# SPDX-FileCopyrightText: 2021 Dalibo
#
# SPDX-License-Identifier: GPL-3.0-or-later

from __future__ import annotations

from typing import Any

from . import hook_relay
from .settings import Settings


def do(settings: Settings, env: dict[str, Any] | None = None, header: str = "") -> None:
    if env is None:
        env = {}
    hook = hook_relay(settings)
    hook.site_configure_install(settings=settings, header=header, env=env)


def undo(settings: Settings) -> None:
    hook = hook_relay(settings)
    hook.site_configure_uninstall(settings=settings)


def check(settings: Settings, *, partial: bool = False) -> bool:
    """Check the installation.

    Return True if the installation is complete (or partial, if partial=True).
    """
    hook = hook_relay(settings)
    results = (
        status
        for outcome in hook.site_configure_check(settings=settings, log=not partial)
        for status in outcome
    )
    if partial:
        return any(results)
    return all(results)
